TerminalAdapter

Struct TerminalAdapter 

pub struct TerminalAdapter { /* private fields */ }

Implementations

Source

impl TerminalAdapter

pub fn new() -> Self

pub fn with_color(color: bool) -> Self

pub fn render_image_artifact_set_summary(artifacts: &[&Artifact]) -> String

Build a human-readable summary for a set of image artifacts.

Used by ta draft view to display a summary line like “42 PNG frames, 1024×1024, 380 MB” when a draft contains image artifacts.

pub fn render_binary_artifact_set_summary(artifacts: &[&Artifact]) -> String

Build a human-readable summary for a set of binary artifacts.

Returns a line like "3 binary files (12.4 MB total)" or an empty string if there are no ArtifactKind::Binary artifacts in the set.

pub fn render_text_artifact_set_summary(artifacts: &[&Artifact]) -> String

Build a human-readable summary for a set of text artifacts.

Returns a line like "2 text files" or an empty string if there are no ArtifactKind::Text artifacts in the set.

pub fn render_video_artifact_set_summary(artifacts: &[&Artifact]) -> String

Build a human-readable summary for a set of video artifacts.

Returns a line like "2 MP4 video files, 1920×1080, 24fps" or an empty string if there are no ArtifactKind::Video artifacts in the set.