Module plugin

Module plugin 

Structs

DiscoveredPlugin
A discovered plugin with its manifest and source path.
PluginManifest
Parsed channel.toml plugin manifest.

Enums

PluginError
Errors from plugin operations.
PluginProtocol
Protocol used by an external channel plugin.
PluginSource
Where a plugin was discovered from.

Functions

copy_dir_contents_public
Recursively copy directory contents (public wrapper for plugin_resolver).
discover_plugins
Discover channel plugins from standard directories.
install_plugin
Install a channel plugin from a source directory to the target plugin dir.