Module secret_scan

Module secret_scan 

Structs

SecretFinding
A single secret finding produced by the scanner.

Functions

print_block_cta
Print the block CTA when SecretScanMode::Block aborts apply.
print_findings
Print findings to stderr and return whether any were found.
scan_for_secrets
Scan text (the text content of file_path) for secret patterns. Returns a list of findings with redacted context lines.