validate_against_plan

Function validate_against_plan 

pub fn validate_against_plan(
    artifacts: &[Artifact],
    phase_id: &str,
    phase_title: &str,
) -> PlanValidationResult
Validate artifacts against plan expectations.

Checks that the draft has meaningful content and that artifacts are described. This is called by ta draft build when a goal has a plan_phase.