pub fn load_constitution(
staging_path: &Path,
config: &SupervisorRunConfig,
) -> Option<String>Expand description
Load the constitution text from the configured path or common fallback locations.
pub fn load_constitution(
staging_path: &Path,
config: &SupervisorRunConfig,
) -> Option<String>Load the constitution text from the configured path or common fallback locations.