Structs
- Discovered
Plugin - A discovered plugin with its manifest and source path.
- Plugin
Manifest - Parsed
channel.tomlplugin manifest.
Enums
- Plugin
Error - Errors from plugin operations.
- Plugin
Protocol - Protocol used by an external channel plugin.
- Plugin
Source - Where a plugin was discovered from.
Functions
- copy_
dir_ contents_ public - Recursively copy directory contents (public wrapper for plugin_resolver).
- discover_
plugins - Discover channel plugins from standard directories.
- install_
plugin - Install a channel plugin from a source directory to the target plugin dir.