pub fn check_requirements(
manifest: &ProjectManifest,
project_root: &Path,
) -> Vec<(String, String)>Expand description
Check all required plugins from a manifest against installed plugins.
Returns a list of (name, issue) for any plugin that is missing or below the required version. Used by daemon startup to enforce requirements.