Structs
- Platform
Download - Download info for a specific platform.
- Registry
Client - Registry client for fetching and caching the plugin index.
- Registry
Index - Registry index — the top-level JSON structure.
- Registry
Plugin Entry - A single plugin’s registry entry.
- Registry
Version - A specific version’s release information.
- Resolved
Plugin - A fully resolved plugin download target.
Enums
- Registry
Error - Errors from registry operations.
Constants
- DEFAULT_
CACHE_ TTL_ SECS - Default cache TTL in seconds (1 hour).
- DEFAULT_
REGISTRY_ URL - Default registry URL.
Functions
- detect_
platform - Detect the current platform and return the registry platform key.