Structs
- Secret
Finding - A single secret finding produced by the scanner.
Functions
- print_
block_ cta - Print the block CTA when
SecretScanMode::Blockaborts apply. - print_
findings - Print findings to stderr and return whether any were found.
- scan_
for_ secrets - Scan
text(the text content offile_path) for secret patterns. Returns a list of findings with redacted context lines.